@@ -207,6 +207,10 @@ TLV_TYPE_DESKTOP_SCREENSHOT_PE32DLL_BUFFER = TLV_META_TYPE_STRING | 3010
 TLV_TYPE_DESKTOP_SCREENSHOT_PE64DLL_LENGTH = TLV_META_TYPE_UINT   | 3011
 TLV_TYPE_DESKTOP_SCREENSHOT_PE64DLL_BUFFER = TLV_META_TYPE_STRING | 3012
 TLV_TYPE_KEYSCAN_TRACK_ACTIVE_WINDOW       = TLV_META_TYPE_BOOL   | 3013
+TLV_TYPE_KEYS_SEND                         = TLV_META_TYPE_STRING | 3014
+TLV_TYPE_MOUSE_ACTION                      = TLV_META_TYPE_UINT   | 3015
+TLV_TYPE_MOUSE_X                           = TLV_META_TYPE_UINT   | 3016
+TLV_TYPE_MOUSE_Y                           = TLV_META_TYPE_UINT   | 3017
 
 ##
 #
